@@ -16,8 +16,10 @@ from cli.commands.save import save
 from cli.commands.queue import queue
 from cli.commands.browse import browse
 from cli.commands.history import history
+from cli.commands.toggle import toggle
 from cli.commands.top import top
 from cli.commands.search import search
+from cli.commands.seek import seek
 
 
 # CLI group
@@ -46,5 +48,7 @@ cli.add_command(save)
 cli.add_command(queue)
 cli.add_command(browse)
 cli.add_command(history)
+cli.add_command(toggle)
 cli.add_command(top)
 cli.add_command(search)
+cli.add_command(seek)
